@@ -44,37 +44,37 @@ Log mode for information for processing information
 
 /* Types */
 #define CODES_TYPE_UNDEFINED GRIB_TYPE_UNDEFINED
-#define CODES_TYPE_LONG GRIB_TYPE_LONG
-#define CODES_TYPE_DOUBLE GRIB_TYPE_DOUBLE
-#define CODES_TYPE_STRING GRIB_TYPE_STRING
-#define CODES_TYPE_BYTES GRIB_TYPE_BYTES
-#define CODES_TYPE_SECTION GRIB_TYPE_SECTION
-#define CODES_TYPE_LABEL GRIB_TYPE_LABEL
-#define CODES_TYPE_MISSING GRIB_TYPE_MISSING
+#define CODES_TYPE_LONG      GRIB_TYPE_LONG
+#define CODES_TYPE_DOUBLE    GRIB_TYPE_DOUBLE
+#define CODES_TYPE_STRING    GRIB_TYPE_STRING
+#define CODES_TYPE_BYTES     GRIB_TYPE_BYTES
+#define CODES_TYPE_SECTION   GRIB_TYPE_SECTION
+#define CODES_TYPE_LABEL     GRIB_TYPE_LABEL
+#define CODES_TYPE_MISSING   GRIB_TYPE_MISSING
 
 /* Missing values */
-#define CODES_MISSING_LONG GRIB_MISSING_LONG
+#define CODES_MISSING_LONG   GRIB_MISSING_LONG
 #define CODES_MISSING_DOUBLE GRIB_MISSING_DOUBLE
 
 /*set spec flags*/
 #define CODES_UTIL_SET_SPEC_FLAGS_ONLY_PACKING GRIB_UTIL_SET_SPEC_FLAGS_ONLY_PACKING
 
 /* Dump option flags*/
-#define CODES_DUMP_FLAG_READ_ONLY GRIB_DUMP_FLAG_READ_ONLY
-#define CODES_DUMP_FLAG_DUMP_OK GRIB_DUMP_FLAG_DUMP_OK
-#define CODES_DUMP_FLAG_VALUES GRIB_DUMP_FLAG_VALUES
-#define CODES_DUMP_FLAG_CODED GRIB_DUMP_FLAG_CODED
-#define CODES_DUMP_FLAG_OCTECT GRIB_DUMP_FLAG_OCTECT
-#define CODES_DUMP_FLAG_ALIASES GRIB_DUMP_FLAG_ALIASES
-#define CODES_DUMP_FLAG_TYPE GRIB_DUMP_FLAG_TYPE
-#define CODES_DUMP_FLAG_HEXADECIMAL GRIB_DUMP_FLAG_HEXADECIMAL
-#define CODES_DUMP_FLAG_NO_DATA GRIB_DUMP_FLAG_NO_DATA
-#define CODES_DUMP_FLAG_ALL_DATA GRIB_DUMP_FLAG_ALL_DATA
+#define CODES_DUMP_FLAG_READ_ONLY      GRIB_DUMP_FLAG_READ_ONLY
+#define CODES_DUMP_FLAG_DUMP_OK        GRIB_DUMP_FLAG_DUMP_OK
+#define CODES_DUMP_FLAG_VALUES         GRIB_DUMP_FLAG_VALUES
+#define CODES_DUMP_FLAG_CODED          GRIB_DUMP_FLAG_CODED
+#define CODES_DUMP_FLAG_OCTET          GRIB_DUMP_FLAG_OCTET
+#define CODES_DUMP_FLAG_ALIASES        GRIB_DUMP_FLAG_ALIASES
+#define CODES_DUMP_FLAG_TYPE           GRIB_DUMP_FLAG_TYPE
+#define CODES_DUMP_FLAG_HEXADECIMAL    GRIB_DUMP_FLAG_HEXADECIMAL
+#define CODES_DUMP_FLAG_NO_DATA        GRIB_DUMP_FLAG_NO_DATA
+#define CODES_DUMP_FLAG_ALL_DATA       GRIB_DUMP_FLAG_ALL_DATA
 #define CODES_DUMP_FLAG_ALL_ATTRIBUTES GRIB_DUMP_FLAG_ALL_ATTRIBUTES
 
 /* codes_nearest flags */
-#define CODES_NEAREST_SAME_GRID GRIB_NEAREST_SAME_GRID
-#define CODES_NEAREST_SAME_DATA GRIB_NEAREST_SAME_DATA
+#define CODES_NEAREST_SAME_GRID  GRIB_NEAREST_SAME_GRID
+#define CODES_NEAREST_SAME_DATA  GRIB_NEAREST_SAME_DATA
 #define CODES_NEAREST_SAME_POINT GRIB_NEAREST_SAME_POINT
 
 /*! Iteration is carried out on all the keys available in the message
